# [Recursion](https://en.wikipedia.org/wiki/Recursion_(computer_science))

A few simple examples of recursive algorithms.

## Resources

- [https://www.khanacademy.org/computing/computer-science/algorithms/recursive-algorithms/a/recursion](https://www.khanacademy.org/computing/computer-science/algorithms/recursive-algorithms/a/recursion)